<?php
if ( ! class_exists( 'WP_List_Table' ) ) {
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}
class Push_Report extends WP_List_Table {

    /**
     * Constructor, we override the parent to pass our own arguments
     * We usually focus on three parameters: singular and plural labels, as well as whether the class supports AJAX.
     */
    function __construct() {
        parent::__construct( array(
            'singular'=> 'Push', //Singular label
            'plural' => 'Push', //plural label, also this well be one of the table css class
            'ajax'   => false //We won't support Ajax for this table
        ) );
    }
    function get_columns() {
        return $columns= array(
            'push'=>__('PUSH'),
            'subs'=>__('SUBSCRIBERS'),
            'status'=>__('STATUS'),
            'delivered'=>__('DELIVERED'),
            'clicked'=>__('CLICKS'),
            'sent'=>__('SENT')
        );
    }

    function get_sortable_columns() {
        return $sortable = array(

        );
    }

    public function column_default( $item, $column_name ) {
        switch ( $column_name ) {
            case 'push':
                return $item->title;
            case 'sent':
                return $item->created_at;
            case 'status':
                switch($item->status){
                    case 0:
                        return 'Pending';
                    case 1:
                        return 'Sending';
                    case 2:
                        return 'Sent';
                }
                break;
            default:
                return $item->$column_name;
        }
    }

    function prepare_items() {
        $screen = get_current_screen();
        $perpage = 10;
        $paged = !empty($_GET["paged"]) ? $_GET["paged"] : ’;
        //Page Number
        if(empty($paged) || !is_numeric($paged) || $paged<=0 ){
            $paged=1;
        }

        $feedify_licence_key = get_option('feedify_licence_key');
        $feedify_domain_key = get_option('feedify_domain_key');

        $feedify = new FeedifyAPI($feedify_domain_key, $feedify_licence_key);
        $push_reports = $feedify->get_report($paged, $perpage);
        $totalpages = ceil($push_reports->total/$perpage);
        if($push_reports) {
            $this->set_pagination_args( array(
                "total_items" => $push_reports->total,
                "total_pages" => $totalpages,
                "per_page" => $perpage,
            ) );
        }

        $columns = $this->get_columns();
        $hidden = array();
        $sortable = $this->get_sortable_columns();

        $this->_column_headers = array($columns, $hidden, $sortable);
        //$this->items = json_decode(json_encode($push_reports->records), true);
        $this->items = $push_reports->records;

        //echo '<pre>';print_r($this->items);

    }

    /*function display_rows() {
        $records = $this->items;
        list( $columns, $hidden ) = $this->get_column_info();
    }*/

}
$push_report = new Push_Report();
$push_report->prepare_items();
?>
<div class="wrap">
    <?php screen_icon(); ?>
    <h1 class="wp-heading-inline">
		Push Report
		<a href="<?php echo admin_url( '/admin.php?page=feedify-send-push' ) ?>" class="page-title-action">Send Push</a>
	</h1>

    <hr class="wp-header-end">
    <?php $push_report->display(); ?>
</div>